TxOutTarget

Enum TxOutTarget 

pub enum TxOutTarget {
    ToKey {
        key: [u8; 32],
    },
    ToTaggedKey {
        key: [u8; 32],
        view_tag: u8,
    },
}
Type of output formats, only TxOutTarget::ToKey and TxOutTarget::ToTaggedKey are used, other formats are legacy to the original cryptonote implementation.

Variants



ToKey

A one-time public key output.

Fields

key: [u8; 32]

The one-time public key of that output.



ToTaggedKey

A one-time public key output with a view tag.

Fields

key: [u8; 32]

The one-time public key of that output.

view_tag: u8

The view tag of that output.

Implementations

Source

impl TxOutTarget

pub fn as_one_time_key(&self) -> Option<PublicKey>

Returns the one-time public key if this is a TxOutTarget::ToKey or TxOutTarget::ToTaggedKey and None otherwise.

pub fn check_view_tag(&self, rv: PublicKey, index: usize) -> bool

Derives a view tag and checks if it matches the outputs view tag, if no view tag is present the default is true.