pub enum SubField {
TxPublicKey(PublicKey),
Nonce(Vec<u8>),
Padding(u8),
MergeMining(VarInt, Hash),
AdditionalPublickKey(Vec<PublicKey>),
MysteriousMinerGate(Vec<u8>),
}Expand description
Each sub-field contains a sub-field tag followed by sub-field content of fixed or variable
length, in variable length case the length is encoded with a VarInt before the content
itself.
Variants
TxPublicKey(PublicKey)
Transaction public key, fixed length of 32 bytes.
Nonce(Vec<u8>)
255 bytes limited nonce, can contain an encrypted or unencrypted payment id, variable length.
Padding(u8)
Padding size is limited to 255 null bytes, variable length.
MergeMining(VarInt, Hash)
Merge mining infos: depth and merkle_root, fixed length of one VarInt and 32 bytes
hash.
AdditionalPublickKey(Vec<PublicKey>)
Additional public keys for Subaddresses outputs,
variable length of n additional public keys.
MysteriousMinerGate(Vec<u8>)
Mysterious MinerGate, variable length.