pub enum TxOutTarget {
ToKey {
key: [u8; 32],
},
ToTaggedKey {
key: [u8; 32],
view_tag: u8,
},
}Expand description
Type of output formats, only TxOutTarget::ToKey and TxOutTarget::ToTaggedKey are used, other formats are legacy to the
original cryptonote implementation.
Variants
Implementations
Sourceimpl TxOutTarget
impl TxOutTarget
Sourcepub fn as_one_time_key(&self) -> Option<PublicKey>
pub fn as_one_time_key(&self) -> Option<PublicKey>
Returns the one-time public key if this is a TxOutTarget::ToKey or TxOutTarget::ToTaggedKey and None otherwise.
Sourcepub fn check_view_tag(&self, rv: PublicKey, index: usize) -> bool
pub fn check_view_tag(&self, rv: PublicKey, index: usize) -> bool
Derives a view tag and checks if it matches the outputs view tag, if no view tag is present the default is true.